@@ -16,9 +16,9 @@ pub struct HgBranchConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for HgBranchConfig<'a> {
+impl Default for HgBranchConfig<'_> {
     fn default() -> Self {
-        HgBranchConfig {
+        Self {
             symbol: " ",
             style: "bold purple",
             format: "on [$symbol$branch(:$topic)]($style) ",
