@@ -18,9 +18,9 @@ pub struct JavaConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for JavaConfig<'a> {
+impl Default for JavaConfig<'_> {
     fn default() -> Self {
-        JavaConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             disabled: false,
